@@ -12,7 +12,7 @@ Number::Tolerant::Union - unions of tolerance ranges
 
 version 1.42
 
- $Id: /my/cs/projects/tolerant/trunk/lib/Number/Tolerant/Union.pm 18205 2006-01-28T00:48:56.763611Z rjbs  $
+ $Id: /my/cs/projects/tolerant/trunk/lib/Number/Tolerant/Union.pm 22014 2006-05-11T23:00:09.416140Z rjbs  $
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,9 @@ tolerance will function on a union of tolerances, as listed below.
 
 =head1 METHODS
 
-=head2 C<< Number::Tolerant::Union->new( @options ) >>
+=head2 new
+
+  my $union = Number::Tolerant::Union->new(@list_of_tolerances);
 
 There is a C<new> method on the Number::Tolerant::Union class, but unions are
 meant to be created with the C<|> operator on a Number::Tolerant tolerance.
